@@ -1,6 +1,6 @@
 package Enbld::Feature;
 
-use 5.012;
+use strict;
 use warnings;
 
 require Enbld::Error;
